@@ -9,14 +9,14 @@ from .jobs import Jobs
 from .gpu_types import GpuTypes
 from .environments import Environments
 from .exceptions import ApiError
-
-CONFIG_DIR = os.path.expanduser(
-    os.environ.get("TRAINML_CONFIG_DIR") or "~/.trainml"
-)
+from .connections import Connections
 
 
 class TrainML(object):
     def __init__(self, **kwargs):
+        CONFIG_DIR = os.path.expanduser(
+            os.environ.get("TRAINML_CONFIG_DIR") or "~/.trainml"
+        )
         try:
             with open(f"{CONFIG_DIR}/environment.json", "r") as file:
                 env_str = file.read().replace("\n", "")
@@ -34,6 +34,7 @@ class TrainML(object):
         self.jobs = Jobs(self)
         self.gpu_types = GpuTypes(self)
         self.environments = Environments(self)
+        self.connections = Connections(self)
         self.api_url = (
             kwargs.get("api_url")
             or os.environ.get("TRAINML_API_URL")
@@ -110,5 +111,6 @@ class TrainML(object):
                         aiohttp.WSMsgType.CLOSED,
                         aiohttp.WSMsgType.ERROR,
                     ):
+                        await ws.close()
                         break
                     msg_handler(msg)
